# Go ChatGPT


## Quick start
***「go_chatgpt」* 是一个快速调用 openai chatgpt api 的网页封装**

> ***「go_subtitle」 is a quick call to openai chatgpt api web page encapsulation***


### Setup
**项目需要运行在包含 *[python3.8.16](https://www.python.org/downloads/release/python-3816/)* 的环境中**

> ***The project needs runs in an environment containing [python3.8.16](https://www.python.org/downloads/release/python-3816/)***

**建议通过 *[miniconda](https://docs.conda.io/en/latest/miniconda.html)* 安装 *python* 以便管理环境**

> **It is recommended to install python through *[miniconda](https://docs.conda.io/en/latest/miniconda.html)* to manage the environment**

```shell
# 安装python3.8版本
conda create -n chatgpt python=3.8 
```

**你可以通过下面的命令安装此项目最新的版本**

> ***You can install the project latest version using the following command***

```shell
# 从PyPI安装
pip install -U go_chatgpt

# 从GitHub安装
pip install git+https://github.com/RedHeartSecretMan/go_chatgpt.git
```

**你需要创建 *OpenAI* 账号获取 *api-key* 以使用**
> ***You need to create an OpenAI account to get the api-key to use***


### End
**项目现在是一个可用的*demo*，计划在*23*年*6*月份左右完善**

> ***The project is now an available demo, which is planned to be completed around June in 23***